/* 
   Copyright (c) 2001 Paul Campbell - paul@taniwha.com
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
                           
#include <fcntl.h>
#include "cresources.h"


res_env::res_env(const char *name)
{
	rf = ::res_open_env(name);
	if (rf == NULL) {
		delete this;
		return;
	}
}
res_env::~res_env()
{
	::res_close_env(rf);
}

int res_env::stat(const char *file_name, struct stat *buf)
{
	return(::res_rstat(rf, file_name, buf));
}

res_fd *res_env::open(const char *name)
{
	struct RES_FD *fd;
	fd = ::res_open(rf, name, O_RDONLY);
	if (fd == NULL)
		return(NULL);
	res_fd *x = new res_fd(fd);
	if (x == NULL) {
		::res_close(fd);
		return(NULL);
	}
	return(x);
}

res_file *res_env::fopen(const char *name)
{
	struct RES_FILE *f;
	f = ::res_fopen(rf, name, "r");
	if (f == NULL)
		return(NULL);
	res_file *x = new res_file(f);
	if (x == NULL) {
		::res_fclose(f);
		return(NULL);
	}
	return(x);
}

res_dir *res_env::opendir(const char *name)
{
	struct RES_DIR *dp;
	dp = ::res_opendir(rf, name);
	if (dp == NULL)
		return(NULL);
	res_dir *x = new res_dir(dp);
	if (x == NULL) {
		::res_closedir(dp);
		return(NULL);
	}
	return(x);
}

res_fd::res_fd(struct RES_FD *xfd)
{
	fd = xfd;
}
res_fd::~res_fd()
{
	::res_close(fd);
}

int res_fd::read(void *buf, size_t count)
{
	return(::res_read(fd, buf, count));
}

int res_fd::fstat(struct stat *buf)
{
	return(::res_fstat(fd, buf));
}

int res_fd::lseek(off_t offset, int whence)
{
	return(::res_lseek(fd, offset, whence));
}

res_file::res_file(struct RES_FILE *xf)
{
	f  = xf;
}
res_file::~res_file()
{
	::res_fclose(f);
}

int res_file::fread(void *ptr, size_t size, size_t nmemb)
{
	return(::res_fread(ptr, size, nmemb, f));
}
void res_file::clearerr()
{
	::res_clearerr(f);
}

int res_file::feof() 
{
	return (::res_feof(f));
}

int res_file::ferror()
{
	return (::res_ferror(f));
}

int res_file::fgetc()
{
	return(::res_fgetc(f));
}

int res_file::ungetc(int c)
{
	return(::res_ungetc(c, f));
}
	
char *res_file::fgets(char *s, int size)
{
	return(::res_fgets(s, size, f));
}

int res_file::fseek( long offset, int whence)
{
	return(::res_fseek(f, offset, whence));
}

int res_file::ftell()
{
	return(::res_ftell(f));
}

int res_file::rewind()
{
	::res_rewind(f);
}

int res_file::fgetpos(fpos_t *pos) 
{
	return(::res_fgetpos(f, pos));
}

int res_file::fsetpos(fpos_t *pos)
{
	return(::res_fsetpos(f, pos));
}

res_dir::res_dir(struct RES_DIR *xdp)
{
	dp = xdp;
}

res_dir::~res_dir()
{
	::res_closedir(dp);
}

struct dirent *res_dir::readdir()
{
	return(::res_readdir(dp));
}

off_t res_dir::telldir()
{
	return(::res_telldir(dp));
}

void res_dir::seekdir(off_t offset)
{
	return(::res_seekdir(dp, offset));
}

void res_dir::rewinddir()
{
	::res_rewinddir(dp);
}
